Rdocumentation
powered by
Learn R Programming
DescribeDisplay (version 0.2.5)
dd_tour_axes: Describe display tour axis Return representation of axes for specified plot
Description
Describe display tour axis Return representation of axes for specified plot
Usage
dd_tour_axes(plot)
Arguments
plot
list of information of a plot